# FUTURES

### MARKET DATA ENDPOINTS FUTURES

GET /fapi/v1/constituents

GET /futures/data/delivery-price

GET /fapi/v1/fundingInfo

GET /futures/data/basis

### TRADING ENDPOINTS FUTURES

GET /fapi/v1/order/asyn

GET /fapi/v1/order/asyn/id

GET /fapi/v1/trade/asyn

GET /fapi/v1/trade/asyn/id

GET /fapi/v1/constituents

### MARKET DATA STREAMS FUTURES

!assetIndex@arr

<.assetSymbol.>@assetIndex

# SPOT

### MARKET DATA ENDPOINTS SPOT

GET /api/v3/ticker/tradingDay

### MARKET DATA STREAM SPOT

<.symbol.>@avgPrice

---

Последний просмотр Futures 2024-01-24

Последний просмотр Spot 2024-01-24
